pub struct EmbeddedScriptProblemRecipe {
pub script: String,
pub args: Vec<String>,
}Expand description
Recipe for the problem implemented by an embedded script.
Fields
script: StringEmbedded script code.
args: Vec<String>Command line arguments that are passed to the script.